==> clash-ghc-1.6.3-3-x86_64.pkg.tar.zst: usr/share/haskell/register/clash-ghc.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 clash-ghc
version:              1.6.3
visibility:           public
id:                   clash-ghc-1.6.3-3DQIhffAl4b4b6u9HOkUDr
key:                  clash-ghc-1.6.3-3DQIhffAl4b4b6u9HOkUDr
license:              BSD-2-Clause
copyright:
    Copyright © 2012-2016, University of Twente,
    2016-2017, Myrtle Software Ltd,
    2017-2019, QBayLogic B.V., Google Inc.

maintainer:           QBayLogic B.V. <devops@qbaylogic.com>
author:               The Clash Authors
homepage:             https://clash-lang.org/
synopsis:
    Clash: a functional hardware description language - GHC frontend

description:
    Clash is a functional hardware description language that borrows both its
    syntax and semantics from the functional programming language Haskell. The
    Clash compiler transforms these high-level descriptions to low-level
    synthesizable VHDL, Verilog, or SystemVerilog.

    Features of Clash:

    * Strongly typed, but with a very high degree of type inference, enabling both
    safe and fast prototyping using concise descriptions.

    * Interactive REPL: load your designs in an interpreter and easily test all
    your component without needing to setup a test bench.

    * Higher-order functions, with type inference, result in designs that are
    fully parametric by default.

    * Synchronous sequential circuit design based on streams of values, called
    @Signal@s, lead to natural descriptions of feedback loops.

    * Support for multiple clock domains, with type safe clock domain crossing.


    This package provides:

    * Clash Compiler binary using GHC/Haskell as a frontend


    Prelude library: <https://hackage.haskell.org/package/clash-prelude>

category:             Hardware
abi:                  1dc24781fa1a1d436b8119f53c09cb82
exposed:              True
exposed-modules:
    Clash.GHC.Evaluator Clash.GHC.Evaluator.Primitive
    Clash.GHC.GenerateBindings Clash.GHC.LoadModules
    Clash.GHC.NetlistTypes Clash.GHC.PartialEval
    Clash.GHC.PartialEval.Eval Clash.GHC.PartialEval.Primitive
    Clash.GHC.PartialEval.Quote Clash.GHCi.Common Clash.Main

hidden-modules:
    Clash.GHCi.Leak Clash.GHCi.UI Clash.GHCi.UI.Info
    Clash.GHCi.UI.Monad Clash.GHCi.UI.Tags Clash.GHC.ClashFlags
    Clash.GHC.GHC2Core Clash.GHC.LoadInterfaceFiles Clash.GHC.Util
    Paths_clash_ghc Clash.GHCi.Util

import-dirs:          /usr/lib/ghc-9.0.2/site-local/clash-ghc-1.6.3
library-dirs:         /usr/lib/ghc-9.0.2/site-local/clash-ghc-1.6.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/clash-ghc
hs-libraries:         HSclash-ghc-1.6.3-3DQIhffAl4b4b6u9HOkUDr
depends:
    Cabal-3.4.1.0 array-0.5.4.0 base-4.15.1.0 bytestring-0.10.12.1
    clash-lib-1.6.3-GtTxLAm3K3pIVMHhcBEguB
    clash-prelude-1.6.3-8GVs5Auz40B2gIAOAk30vB
    concurrent-supply-0.1.8-5QjBQNJJw1v9gkAZCp5YOK containers-0.6.4.1
    data-binary-ieee754-0.4.4-6nKeQnWkGoLJGejCHaRaWS deepseq-1.4.5.0
    directory-1.3.6.2 exceptions-0.10.4
    extra-1.7.10-HSRmSjpfi0b20DVd5qjBWY filepath-1.4.2.1 ghc-9.0.2
    ghc-bignum-1.1 ghc-boot-9.0.2 ghc-prim-0.7.0
    ghc-typelits-extra-0.4.3-Cxjo3BBaAelBFlYqmlzJXj
    ghc-typelits-knownnat-0.7.6-G456Q8WMj3dIojzGIHk2E6
    ghc-typelits-natnormalise-0.7.6-BNS29zBiyRJGpCPt1bYict ghci-9.0.2
    hashable-1.4.0.2-KL4gFPtdNMSEvjFKBn8dZI haskeline-0.8.2
    lens-5.1.1-4M5zSd24oOB3ODyeRSY1iF mtl-2.2.2
    primitive-0.7.4.0-9KmreeHGuurHfroshPZGcK process-1.6.13.2
    reflection-2.1.6-G6vYFSps3HgA7OHM3JMybY
    split-0.2.3.4-DRBi5ovdYcUMrsGeA095B template-haskell-2.17.0.0
    text-1.2.5.0 time-1.9.3 transformers-0.5.6.2
    uniplate-1.6.13-FaNu6p3HDjeLi97b1NYCVt unix-2.7.2.2
    unordered-containers-0.2.19.1-Egpruffujfv1ZeuVmASDK2
    utf8-string-1.0.2-9eFA57BgKXNHtjvfuIOq9f
    vector-0.12.3.1-6Jse5cnDdy2CJPq6wEcUm1

haddock-interfaces:   /usr/share/doc/clash-ghc/html/clash-ghc.haddock
haddock-html:         /usr/share/doc/clash-ghc/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> clash-ghc-1.6.3-10-x86_64.pkg.tar.zst: usr/share/haskell/register/clash-ghc.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 clash-ghc
version:              1.6.3
visibility:           public
id:                   clash-ghc-1.6.3-8CbSAR0zujCEt2NSyID8Ye
key:                  clash-ghc-1.6.3-8CbSAR0zujCEt2NSyID8Ye
license:              BSD-2-Clause
copyright:
    Copyright © 2012-2016, University of Twente,
    2016-2017, Myrtle Software Ltd,
    2017-2019, QBayLogic B.V., Google Inc.

maintainer:           QBayLogic B.V. <devops@qbaylogic.com>
author:               The Clash Authors
homepage:             https://clash-lang.org/
synopsis:
    Clash: a functional hardware description language - GHC frontend

description:
    Clash is a functional hardware description language that borrows both its
    syntax and semantics from the functional programming language Haskell. The
    Clash compiler transforms these high-level descriptions to low-level
    synthesizable VHDL, Verilog, or SystemVerilog.

    Features of Clash:

    * Strongly typed, but with a very high degree of type inference, enabling both
    safe and fast prototyping using concise descriptions.

    * Interactive REPL: load your designs in an interpreter and easily test all
    your component without needing to setup a test bench.

    * Higher-order functions, with type inference, result in designs that are
    fully parametric by default.

    * Synchronous sequential circuit design based on streams of values, called
    @Signal@s, lead to natural descriptions of feedback loops.

    * Support for multiple clock domains, with type safe clock domain crossing.


    This package provides:

    * Clash Compiler binary using GHC/Haskell as a frontend


    Prelude library: <https://hackage.haskell.org/package/clash-prelude>

category:             Hardware
abi:                  7d5061ab5dd4aa9333f4631799726dda
exposed:              True
exposed-modules:
    Clash.GHC.Evaluator Clash.GHC.Evaluator.Primitive
    Clash.GHC.GenerateBindings Clash.GHC.LoadModules
    Clash.GHC.NetlistTypes Clash.GHC.PartialEval
    Clash.GHC.PartialEval.Eval Clash.GHC.PartialEval.Primitive
    Clash.GHC.PartialEval.Quote Clash.GHCi.Common Clash.Main

hidden-modules:
    Clash.GHCi.Leak Clash.GHCi.UI Clash.GHCi.UI.Info
    Clash.GHCi.UI.Monad Clash.GHCi.UI.Tags Clash.GHC.ClashFlags
    Clash.GHC.GHC2Core Clash.GHC.LoadInterfaceFiles Clash.GHC.Util
    Paths_clash_ghc Clash.GHCi.Util

import-dirs:          /usr/lib/ghc-9.0.2/site-local/clash-ghc-1.6.3
library-dirs:         /usr/lib/ghc-9.0.2/site-local/clash-ghc-1.6.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/clash-ghc
hs-libraries:         HSclash-ghc-1.6.3-8CbSAR0zujCEt2NSyID8Ye
depends:
    Cabal-3.4.1.0 array-0.5.4.0 base-4.15.1.0 bytestring-0.10.12.1
    clash-lib-1.6.3-9ouhOuTHqD8F9O1fw4Ot2S
    clash-prelude-1.6.3-IdsygC5Wwml5Xn0awiSFrs
    concurrent-supply-0.1.8-L0H8oEpwt2nJDVklpnxHjn containers-0.6.4.1
    data-binary-ieee754-0.4.4-6nKeQnWkGoLJGejCHaRaWS deepseq-1.4.5.0
    directory-1.3.6.2 exceptions-0.10.4
    extra-1.7.10-Kf2XRj88b3O1zhhCmp97WR filepath-1.4.2.1 ghc-9.0.2
    ghc-bignum-1.1 ghc-boot-9.0.2 ghc-prim-0.7.0
    ghc-typelits-extra-0.4.3-EXSGIaX8DO31B0qbyN3pYK
    ghc-typelits-knownnat-0.7.6-GXV2EDyH9bLFgSM8oucWpV
    ghc-typelits-natnormalise-0.7.6-8dwecioDVCuI3HlTWyleyK ghci-9.0.2
    hashable-1.4.0.2-HaS0gz7DKZl5hgkyH0eShz haskeline-0.8.2
    lens-5.1.1-5PPvtF24NNgJOUeY91kG7T mtl-2.2.2
    primitive-0.7.4.0-E4MrerHTNw2LkW7cPHJms9 process-1.6.13.2
    reflection-2.1.6-8xcPaO9xkud8IAxEfi14fX
    split-0.2.3.4-LASty2p7YRr9gFd3RTzW9a template-haskell-2.17.0.0
    text-1.2.5.0 time-1.9.3 transformers-0.5.6.2
    uniplate-1.6.13-28fuNhN8Bl5EA0mq3I9DIW unix-2.7.2.2
    unordered-containers-0.2.19.1-DzqMNL8SmsvLUZuXVD6UYJ
    utf8-string-1.0.2-9eFA57BgKXNHtjvfuIOq9f
    vector-0.12.3.1-DWLcs41oUpGB6FR7Q3d3DL

haddock-interfaces:   /usr/share/doc/clash-ghc/html/clash-ghc.haddock
haddock-html:         /usr/share/doc/clash-ghc/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
